@@ -9,15 +9,16 @@ from typing import TYPE_CHECKING, Any, Hashable, Literal, Mapping, Sequence, cas
 import numpy as np
 import xarray as xr
 from numpy.core.numeric import normalize_axis_index  # type: ignore
-from numpy.typing import ArrayLike, DTypeLike
 
 from . import convert
-from ._docstrings import docfiller_shared
-from ._typing import ArrayOrder, Moments, T_CentralMoments
+from .docstrings import docfiller_decorate
 from .resample import randsamp_freq, resample_data, resample_vals
 from .utils import _axis_expand_broadcast, _shape_insert_axis, _shape_reduce
 
 if TYPE_CHECKING:
+    from numpy.typing import ArrayLike, DTypeLike
+
+    from ._typing import ArrayOrder, Moments, T_CentralMoments
     from .xcentral import xCentralMoments
 
 
@@ -171,7 +172,7 @@ def _central_comoments(
     return out
 
 
-@docfiller_shared
+@docfiller_decorate
 def central_moments(
     x: np.ndarray | tuple[np.ndarray, np.ndarray],
     mom: Moments,
@@ -374,7 +375,7 @@ class CentralMoments(CentralMomentsABC[np.ndarray]):
     ###########################################################################
     # SECTION: To/from xarray
     ###########################################################################
-    @docfiller_shared
+    @docfiller_decorate
     def to_xarray(
         self,
         dims: Hashable | Sequence[Hashable] | None = None,
@@ -472,7 +473,7 @@ class CentralMoments(CentralMomentsABC[np.ndarray]):
 
         return out
 
-    @docfiller_shared
+    @docfiller_decorate
     def to_xcentralmoments(
         self,
         dims: Hashable | Sequence[Hashable] | None = None,
@@ -837,7 +838,7 @@ class CentralMoments(CentralMomentsABC[np.ndarray]):
     ###########################################################################
     # SECTION: Manipulation
     ###########################################################################
-    @docfiller_shared
+    @docfiller_decorate
     def resample_and_reduce(
         self: T_CentralMoments,
         freq: np.ndarray | None = None,
@@ -899,7 +900,7 @@ class CentralMoments(CentralMomentsABC[np.ndarray]):
         else:
             return out
 
-    @docfiller_shared
+    @docfiller_decorate
     def reduce(
         self: T_CentralMoments, axis: int | None = None, **kws
     ) -> T_CentralMoments:
@@ -919,7 +920,7 @@ class CentralMoments(CentralMomentsABC[np.ndarray]):
             self.values, mom_ndim=self.mom_ndim, axis=axis, **kws
         )
 
-    @docfiller_shared
+    @docfiller_decorate
     def block(
         self: T_CentralMoments,
         block_size: int | None = None,
@@ -978,7 +979,7 @@ class CentralMoments(CentralMomentsABC[np.ndarray]):
         )
         return type(self).from_datas(datas=datas, mom_ndim=self.mom_ndim, axis=1, **kws)
 
-    @docfiller_shared
+    @docfiller_decorate
     def reshape(
         self: T_CentralMoments,
         shape: tuple[int, ...],
@@ -1055,7 +1056,7 @@ class CentralMoments(CentralMomentsABC[np.ndarray]):
             **kws,
         )
 
-    @docfiller_shared
+    @docfiller_decorate
     def moveaxis(
         self: T_CentralMoments,
         source: int | tuple[int, ...],
