@@ -6,6 +6,7 @@
 from __future__ import annotations
 
 from typing import (  # TYPE_CHECKING,
+    TYPE_CHECKING,
     Any,
     Hashable,
     Literal,
@@ -18,16 +19,19 @@ from warnings import warn
 
 import numpy as np
 import xarray as xr
-from numpy.typing import DTypeLike
+from module_utilities import cached
 
 from . import convert
-from ._docstrings import docfiller_shared
-from ._typing import Dims, MomDims, Moments, T_CentralMoments
 from .abstract_central import CentralMomentsABC
-from .cached_decorators import gcached
 from .central import CentralMoments
+from .docstrings import docfiller_decorate
 from .utils import _shape_reduce
 
+if TYPE_CHECKING:
+    from numpy.typing import DTypeLike
+
+    from ._typing import Dims, MomDims, Moments, T_CentralMoments
+
 
 # * Utilities
 def _select_axis_dim(
@@ -208,7 +212,7 @@ def _xcentral_comoments(
     return out
 
 
-@docfiller_shared
+@docfiller_decorate
 def xcentral_moments(
     x: xr.DataArray | tuple[xr.DataArray, xr.DataArray],
     mom: Moments,
@@ -358,7 +362,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         return self.dims[-self.mom_ndim :]
 
     # ** top level creation/copy/new
-    @gcached()
+    @cached.prop
     def _template_val(self) -> xr.DataArray:
         """Template for values part of data."""
         return self._xdata[self._weight_index]
@@ -763,7 +767,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         """Create a CentralMoments object from xCentralMoments."""
         return CentralMoments(data=self.data, mom_ndim=self.mom_ndim)
 
-    @gcached()
+    @cached.prop
     def centralmoments_view(self):
         """
         Create CentralMoments view.
@@ -778,7 +782,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         return self.to_centralmoments()
 
     @classmethod
-    @docfiller_shared
+    @docfiller_decorate
     def from_centralmoments(
         cls,
         obj: CentralMoments,
@@ -991,7 +995,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
             )
 
     # ** Manipulation
-    @docfiller_shared
+    @docfiller_decorate
     def resample_and_reduce(
         self,
         freq: np.ndarray | None = None,
@@ -1121,7 +1125,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
             return super()._wrap_axis(axis=axis, default=default, ndim=ndim)
 
     @no_type_check
-    @docfiller_shared
+    @docfiller_decorate
     def reduce(
         self: T_CentralMoments,
         dim: Hashable | None = None,
@@ -1160,7 +1164,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         )
 
     @no_type_check
-    @docfiller_shared
+    @docfiller_decorate
     def block(
         self,
         block_size: int,
@@ -1262,7 +1266,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
     # ** Constructors
     @no_type_check
     @classmethod
-    @docfiller_shared
+    @docfiller_decorate
     def zeros(
         cls: type[T_CentralMoments],
         mom: Moments | None = None,
@@ -1330,7 +1334,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
             ).zero()
 
     @classmethod
-    @docfiller_shared
+    @docfiller_decorate
     def from_data(
         cls,
         data: np.ndarray | xr.DataArray,
@@ -1422,7 +1426,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
     @classmethod
     @no_type_check
-    @docfiller_shared
+    @docfiller_decorate
     def from_datas(
         cls,
         datas: np.ndarray | xr.DataArray,
@@ -1519,7 +1523,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
     @no_type_check
     @classmethod
-    @docfiller_shared
+    @docfiller_decorate
     def from_raw(
         cls,
         raw: np.ndarray | xr.DataArray,
@@ -1673,7 +1677,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
     @no_type_check
     @classmethod
-    @docfiller_shared
+    @docfiller_decorate
     def from_vals(
         cls,
         x: np.ndarray
@@ -1781,7 +1785,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
     @no_type_check
     @classmethod
-    @docfiller_shared
+    @docfiller_decorate
     def from_resample_vals(
         cls,
         x: np.ndarray
